==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/ToolActionCheckboxInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolActionInfoDescriptionMetadata } from "./ToolActionInfoDescriptionMetadata";
import { ToolActionCheckboxInfoDescription } from "./ToolActionCheckboxInfoDescription";
/**
 * @hidden
 */
export let ToolActionCheckboxInfoDescriptionMetadata = /*@__PURE__*/ (() => {
    class ToolActionCheckboxInfoDescriptionMetadata extends Base {
        static b(a) {
            if (ToolActionCheckboxInfoDescriptionMetadata.a == null) {
                ToolActionCheckboxInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ToolActionCheckboxInfoDescriptionMetadata.c(ToolActionCheckboxInfoDescriptionMetadata.a);
            }
            if (a.k(ToolActionCheckboxInfoDescriptionMetadata.a)) {
                return;
            }
            a.ab(ToolActionCheckboxInfoDescriptionMetadata.a);
        }
        static c(a) {
            ToolActionInfoDescriptionMetadata.c(a);
            a.item("IsChecked", "Boolean");
        }
        static d(a) {
            ToolActionCheckboxInfoDescriptionMetadata.b(a);
            a.ad("ToolActionCheckboxInfo", () => new ToolActionCheckboxInfoDescription());
            a.ac("ToolActionCheckboxInfo", ToolActionCheckboxInfoDescriptionMetadata.a);
        }
    }
    ToolActionCheckboxInfoDescriptionMetadata.$t = markType(ToolActionCheckboxInfoDescriptionMetadata, 'ToolActionCheckboxInfoDescriptionMetadata');
    ToolActionCheckboxInfoDescriptionMetadata.a = null;
    return ToolActionCheckboxInfoDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/ToolActionCheckboxInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolActionInfoDescriptionMetadata } from "./ToolActionInfoDescriptionMetadata";
import { ToolActionCheckboxInfoDescription } from "./ToolActionCheckboxInfoDescription";
/**
 * @hidden
 */
export let ToolActionCheckboxInfoDescriptionMetadata = /*@__PURE__*/ (() => {
    class ToolActionCheckboxInfoDescriptionMetadata extends Base {
        static b(a) {
            if (ToolActionCheckboxInfoDescriptionMetadata.a == null) {
                ToolActionCheckboxInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ToolActionCheckboxInfoDescriptionMetadata.c(ToolActionCheckboxInfoDescriptionMetadata.a);
            }
            if (a.k(ToolActionCheckboxInfoDescriptionMetadata.a)) {
                return;
            }
            a.ac(ToolActionCheckboxInfoDescriptionMetadata.a);
        }
        static c(a) {
            ToolActionInfoDescriptionMetadata.c(a);
            a.item("IsChecked", "Boolean");
        }
        static d(a) {
            ToolActionCheckboxInfoDescriptionMetadata.b(a);
            a.ae("ToolActionCheckboxInfo", () => new ToolActionCheckboxInfoDescription());
            a.ad("ToolActionCheckboxInfo", ToolActionCheckboxInfoDescriptionMetadata.a);
        }
    }
    ToolActionCheckboxInfoDescriptionMetadata.$t = markType(ToolActionCheckboxInfoDescriptionMetadata, 'ToolActionCheckboxInfoDescriptionMetadata');
    ToolActionCheckboxInfoDescriptionMetadata.a = null;
    return ToolActionCheckboxInfoDescriptionMetadata;
})();
